@@ -31,7 +31,7 @@ extern "C"
   typedef unsigned int uint32;
   typedef unsigned char uint8;
 
-#define NTLM_VERSION "0.3.7"
+#define NTLM_VERSION "0.3.8"
 
 /*
  * These structures are byte-order dependant, and should not
@@ -99,16 +99,30 @@ extern "C"
   extern void
     buildSmbNtlmAuthRequest (tSmbNtlmAuthRequest * request,
 			     const char *user, const char *domain);
+
+  /* Same as buildSmbNtlmAuthRequest, but won't treat @ in USER as a
+     DOMAIN. */
+  extern void
+    buildSmbNtlmAuthRequest_noatsplit (tSmbNtlmAuthRequest * request,
+				       const char *user, const char *domain);
+
   extern void
     buildSmbNtlmAuthResponse (tSmbNtlmAuthChallenge * challenge,
 			      tSmbNtlmAuthResponse * response,
 			      const char *user, const char *password);
 
-  extern const char *
-  ntlm_check_version (const char *req_version);
+  /* Same as buildSmbNtlmAuthResponse, but won't treat @ in USER as a
+     REALM. */
+  extern void
+    buildSmbNtlmAuthResponse_noatsplit (tSmbNtlmAuthChallenge * challenge,
+					tSmbNtlmAuthResponse * response,
+					const char *user,
+					const char *password);
+
+  extern const char *ntlm_check_version (const char *req_version);
 
 # ifdef __cplusplus
 }
 # endif
 
-#endif /* NTLM_H */
+#endif				/* NTLM_H */
